==> 2.4.zip: piwigo/language/fr_FR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+



$lang['Installation'] = "Installation";
$lang['Basic configuration'] = "Configuration de base";
$lang['Default gallery language'] = "Langue par défaut de la galerie";
$lang['Database configuration'] = "Configuration de la base de données";
$lang['Admin configuration'] = "Configuration du compte administrateur";
$lang['Start Install'] = "Démarrer l'installation";
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = "L'adresse mail doit être de la forme xxx@yyy.eee (exemple : jack@altern.org)";
$lang['Webmaster login'] = "Identifiant de l'administrateur";
$lang['It will be shown to the visitors. It is necessary for website administration'] = "Cet identifiant apparaîtra à tous vos visiteurs. Il vous sert pour administrer le site";
$lang['Connection to server succeed, but it was impossible to connect to database'] = "La connexion au serveur est OK, mais la connection à cette base de données est impossible";
$lang['Can\'t connect to server'] = "Impossible de se connecter au serveur";
$lang['Host'] = "Hôte";
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = "localhost, sql.multimania.com, toto.freesurf.fr";
$lang['User'] = "Utilisateur";
$lang['user login given by your host provider'] = "nom d'utilisateur communiqué par votre hébergeur";
$lang['Password'] = "Mot de passe";
$lang['user password given by your host provider'] = "mot de passe utilisateur communiqué par votre hébergeur";
$lang['Database name'] = "Nom de la base de données";
$lang['also given by your host provider'] = "également fourni par votre hébergeur";
$lang['Database table prefix'] = "Préfixe des noms de tables";
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = "le nom des tables sera précédé de ce préfixe (permet de mieux gérer sa base de données)";
$lang['enter a login for webmaster'] = "veuillez rentrer un pseudo pour le webmaster";
$lang['webmaster login can\'t contain characters \' or "'] = "le pseudo du webmaster ne doit pas comporter les caractères \" et '";
$lang['please enter your password again'] = "veuillez resaisir votre mot de passe";
$lang['Webmaster password'] = "Mot de passe du webmaster";
$lang['Keep it confidential, it enables you to access administration panel'] = "Il doit rester confidentiel, il permet d'accéder à l'écran d'administration.";
$lang['Password [confirm]'] = "Mot de passe [Confirmer]";
$lang['verification'] = "vérification";
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = "Besoin d'aide ? Posez votre question sur le <a href=\"%s\">forum de Piwigo</a>.";
$lang['Webmaster mail address'] = "Adresse e-mail de l'administrateur";
$lang['Visitors will be able to contact site administrator with this mail'] = "Les visiteurs pourront contacter l'administrateur du site par ce mail";
$lang['PHP 5 is required'] = "PHP 5 est requis";
$lang['It appears your webhost is currently running PHP %s.'] = "Apparemment, la version PHP de votre hébergeur est PHP %s.";
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = "Piwigo va essayer de passer en PHP 5 en créant ou modifiant le fichier .htaccess.";
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = "Notez que vous pouvez modifier vous-même la configuration PHP et re-lancer Piwigo ensuite.";
$lang['Try to configure PHP 5'] = "Essayer de configurer PHP 5";
$lang['Sorry!'] = "Désolé!";
$lang['Piwigo was not able to configure PHP 5.'] = "Piwigo n'a pas pu configurer PHP 5.";
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = "Il vous faut contacter le support de votre hébergeur pour savoir comment configurer vous-même PHP 5.";
$lang['Hope to see you back soon.'] = "En espérant vous revoir très prochainement.";
$lang['Congratulations, Piwigo installation is completed'] = 'Félicitations, l\'installation de Piwigo est terminée';

$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Une solution alternative est de copier le texte dans la zone ci-dessous et de le coller dans le fichier "local/config/database.inc.php" (Attention: database.inc.php ne doit contenir que ce qui se trouve dans la zone, pas de retour à la ligne, pas d\'espace)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'La création du fichier de configuration local/config/database.inc.php a échoué.';
$lang['Download the config file'] = 'Télécharger le fichier de configuration';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Vous pouvez télécharger le fichier de configuration et le transférer dans le répertoire local/config de votre installation Piwigo.';
$lang['Just another Piwigo gallery'] = 'Une galerie Piwigo de plus';
$lang['Welcome to my photo gallery'] = 'Bienvenue sur ma galerie photo';
$lang['Welcome to your new installation of Piwigo!'] = 'Bienvenue sur votre nouvelle installtion de Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'N\'hésitez pas à consulter nos forums si vous avez le moindre problème : %s';

?>

==> 14.5.0.zip: piwigo/language/fr_FR/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = "Installation";
$lang['Basic configuration'] = "Configuration de base";
$lang['Default gallery language'] = "Langue par défaut de la galerie";
$lang['Database configuration'] = "Configuration de la base de données";
$lang['Admin configuration'] = "Configuration du compte administrateur";
$lang['Start Install'] = "Démarrer l'installation";
$lang['It will be shown to the visitors. It is necessary for website administration'] = "Cet identifiant apparaîtra à tous vos visiteurs. Il vous sert pour administrer le site";
$lang['Connection to server succeed, but it was impossible to connect to database'] = "La connexion au serveur est OK, mais la connection à cette base de données est impossible";
$lang['Can\'t connect to server'] = "Impossible de se connecter au serveur";
$lang['Host'] = "Hôte";
$lang['localhost or other, supplied by your host provider'] = "localhost ou autre, communiqué par votre hébergeur";
$lang['User'] = "Utilisateur";
$lang['user login given by your host provider'] = "nom d'utilisateur communiqué par votre hébergeur";
$lang['user password given by your host provider'] = "mot de passe utilisateur communiqué par votre hébergeur";
$lang['Database name'] = "Nom de la base de données";
$lang['also given by your host provider'] = "également fourni par votre hébergeur";
$lang['Database table prefix'] = "Préfixe des noms de tables";
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = "le nom des tables sera précédé de ce préfixe (permet de mieux gérer sa base de données)";
$lang['enter a login for webmaster'] = "veuillez rentrer un nom d'utilisateur pour le webmaster";
$lang['webmaster login can\'t contain characters \' or "'] = 'le pseudo du webmestre ne doit pas comporter les caractères " et \'';
$lang['please enter your password again'] = "veuillez resaisir votre mot de passe";
$lang['Keep it confidential, it enables you to access administration panel'] = "Il doit rester confidentiel, il permet d'accéder à l'écran d'administration.";
$lang['Password [confirm]'] = "Mot de passe [Confirmer]";
$lang['verification'] = "vérification";
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = "Besoin d'aide ? Posez votre question sur le <a href=\"%s\">forum de Piwigo</a>.";
$lang['Visitors will be able to contact site administrator with this mail'] = "Les visiteurs pourront contacter l'administrateur du site par ce mail";
$lang['PHP 5 is required'] = 'PHP 5.2 est requis';
$lang['PHP version %s required (you are running on PHP %s)'] = 'Piwigo requiert PHP en version %s (ce serveur tourne sur PHP %s)';
$lang['It appears your webhost is currently running PHP %s.'] = "Apparemment, la version PHP de votre hébergeur est PHP %s.";
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo va essayer de passer en PHP 5.2 en créant ou en modifiant le fichier .htaccess.';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = "Notez que vous pouvez modifier vous-même la configuration PHP et re-lancer Piwigo ensuite.";
$lang['Try to configure PHP 5'] = 'Essayer de configurer PHP 5.2';
$lang['Sorry!'] = 'Désolé !';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo n\'a pas pu configurer PHP 5.2';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = 'Il vous faut contacter le support de votre hébergeur pour savoir comment configurer vous-même PHP 5.2';
$lang['Hope to see you back soon.'] = "En espérant vous revoir très prochainement.";
$lang['Congratulations, Piwigo installation is completed'] = 'Félicitations, l\'installation de Piwigo est terminée';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = 'Une solution alternative est de copier le texte dans la zone ci-dessous et de le coller dans le fichier "local/config/database.inc.php" (Attention: database.inc.php ne doit contenir que ce qui se trouve dans la zone, pas de retour à la ligne, pas d\'espace)';
$lang['Creation of config file local/config/database.inc.php failed.'] = 'La création du fichier de configuration local/config/database.inc.php a échoué.';
$lang['Download the config file'] = 'Télécharger le fichier de configuration';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = 'Vous pouvez télécharger le fichier de configuration et le transférer dans le répertoire local/config de votre installation Piwigo.';
$lang['Just another Piwigo gallery'] = 'Une galerie Piwigo de plus';
$lang['Welcome to my photo gallery'] = 'Bienvenue sur ma galerie photo';
$lang['Welcome to your new installation of Piwigo!'] = 'Bienvenue sur votre nouvelle installation de Piwigo !';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = 'N\'hésitez pas à consulter nos forums si vous avez le moindre problème : %s';
